==> all-in-one-sidebar_0.7.23.orig.tar.xz: defaults/preferences/aios.js <==

/*
 *  AiOS
 **/
pref("extensions.{097d3191-e6fa-4728-9826-b533d755359d}.description", "chrome://aios/locale/lib.properties");
pref("extensions.aios.changelog", "");
pref("extensions.aios.infotips", true);
pref("extensions.aios.vbuttons", true);


/*
 *  General
 **/
pref("extensions.aios.gen.orient", 1);
pref("extensions.aios.collapse", true);
pref("extensions.aios.rightclick", false);

pref("extensions.aios.gen.width.minVal", 200);
pref("extensions.aios.gen.width.minUnit", "px");
pref("extensions.aios.gen.width.defVal", 300);
pref("extensions.aios.gen.width.defUnit", "px");
pref("extensions.aios.gen.width.maxVal", 800);
pref("extensions.aios.gen.width.maxUnit", "px");

pref("extensions.aios.gen.init", "rem");
pref("extensions.aios.gen.toolbar.init", 2);
pref("extensions.aios.gen.switch.init", 2);

pref("extensions.aios.gen.open.init", "rem");

pref("extensions.aios.gen.switch.autoshow", false);
pref("extensions.aios.gen.switch.onlymax", false);
pref("extensions.aios.gen.switch.delay", 500);
pref("extensions.aios.gen.switch.hidemethod", 1);
pref("extensions.aios.gen.switch.width", 6);
pref("extensions.aios.gen.switch.twidth", 2);
pref("extensions.aios.gen.switch.thin", false);
pref("extensions.aios.gen.switch.thinmax", false);
pref("extensions.aios.gen.switch.drag", true);

pref("extensions.aios.cmode.key", 2);
pref("extensions.aios.cmode.switch", 2);
pref("extensions.aios.cmode.tbb", 2);
pref("extensions.aios.cmode.close", 1);

pref("extensions.aios.fs.sidebar", true);
pref("extensions.aios.fs.toolbar", true);
pref("extensions.aios.fs.switch", false);
pref("extensions.aios.fs.restore", true);


/*
 *  Panels
 **/
pref("extensions.aios.dm.sidebar", true);
pref("extensions.aios.dm.layout", true);
pref("extensions.aios.dm.layoutall", false);
pref("extensions.aios.dm.autoopen", true);
pref("extensions.aios.dm.autoclose", false);
pref("extensions.aios.dm.count", true);

pref("extensions.aios.em.sidebar", true);
pref("extensions.aios.em.count", true);

pref("extensions.aios.bm.sidebar", true);
pref("extensions.aios.bm.layout", true);

pref("extensions.aios.hi.sidebar", true);
pref("extensions.aios.hi.layout", true);

pref("extensions.aios.mp.sidebar", true);

pref("extensions.aios.pi.sidebar", true);
pref("extensions.aios.pi.layout", true);
pref("extensions.aios.pi.layoutall", false);

pref("extensions.aios.co.sidebar", true);
pref("extensions.aios.co.layout", true);
pref("extensions.aios.co.layoutall", false);


/*
 *  Menus
 **/
pref("extensions.aios.menus.sidebar.entrydeac", true);
pref("extensions.aios.menus.sidebar.entries", true);
pref("extensions.aios.menus.sidebar.icons", true);
pref("extensions.aios.menus.sidebar.paneltab1", false);
pref("extensions.aios.menus.sidebar.paneltab2", false);
pref("extensions.aios.menus.sidebar.showhide", true);
pref("extensions.aios.menus.sidebar.prefs", true);


/*
 *  Shortcuts - by Dorando
 **/
pref("extensions.aios.keyconf.devmode", false);
pref("extensions.aios.keyconf.nicenames.reverse_order", false);
pref("extensions.aios.keyconf.profile", "main");
pref("extensions.aios.keyconf.warnOnClose", false);
pref("extensions.aios.keyconf.warnOnDuplicate", true);


/*
 *  Misc
 **/
pref("extensions.aios.paneltab.reverse", false);
pref("extensions.aios.paneltab.bm", false);

==> all-in-one-sidebar_0.7.28.orig.tar.xz: defaults/preferences/aios.js <==

/*
 *  AiOS
 **/
pref("extensions.{097d3191-e6fa-4728-9826-b533d755359d}.description", "chrome://aios/locale/lib.properties");
pref("extensions.aios.changelog", "");
pref("extensions.aios.infotips", true);
pref("extensions.aios.vbuttons", true);


/*
 *  General
 **/
pref("extensions.aios.gen.orient", 1);
pref("extensions.aios.collapse", true);
pref("extensions.aios.rightclick", false);

pref("extensions.aios.gen.width.minVal", 200);
pref("extensions.aios.gen.width.minUnit", "px");
pref("extensions.aios.gen.width.defVal", 300);
pref("extensions.aios.gen.width.defUnit", "px");
pref("extensions.aios.gen.width.maxVal", 800);
pref("extensions.aios.gen.width.maxUnit", "px");

pref("extensions.aios.gen.init", "rem");
pref("extensions.aios.gen.toolbar.init", 2);
pref("extensions.aios.gen.switch.init", 2);

pref("extensions.aios.gen.open.init", "rem");

pref("extensions.aios.gen.switch.autoshow", false);
pref("extensions.aios.gen.switch.onlymax", false);
pref("extensions.aios.gen.switch.delay", 500);
pref("extensions.aios.gen.switch.hidemethod", 1);
pref("extensions.aios.gen.switch.width", 6);
pref("extensions.aios.gen.switch.twidth", 2);
pref("extensions.aios.gen.switch.thin", false);
pref("extensions.aios.gen.switch.thinmax", false);
pref("extensions.aios.gen.switch.drag", true);

pref("extensions.aios.cmode.key", 2);
pref("extensions.aios.cmode.switch", 2);
pref("extensions.aios.cmode.tbb", 2);
pref("extensions.aios.cmode.close", 1);

pref("extensions.aios.fs.sidebar", true);
pref("extensions.aios.fs.toolbar", true);
pref("extensions.aios.fs.switch", true);
pref("extensions.aios.fs.restore", true);


/*
 *  Panels
 **/
pref("extensions.aios.dm.sidebar", true);
pref("extensions.aios.dm.layout", true);
pref("extensions.aios.dm.layoutall", false);
pref("extensions.aios.dm.autoopen", true);
pref("extensions.aios.dm.autoclose", false);
pref("extensions.aios.dm.count", true);

pref("extensions.aios.em.sidebar", true);
pref("extensions.aios.em.count", true);

pref("extensions.aios.bm.sidebar", true);
pref("extensions.aios.bm.layout", true);

pref("extensions.aios.hi.sidebar", true);
pref("extensions.aios.hi.layout", true);

pref("extensions.aios.mp.sidebar", true);

pref("extensions.aios.pi.sidebar", false);
pref("extensions.aios.pi.layout", true);
pref("extensions.aios.pi.layoutall", false);

pref("extensions.aios.co.sidebar", true);
pref("extensions.aios.co.layout", true);
pref("extensions.aios.co.layoutall", false);


/*
 *  Menus
 **/
pref("extensions.aios.menus.sidebar.entrydeac", true);
pref("extensions.aios.menus.sidebar.entries", true);
pref("extensions.aios.menus.sidebar.icons", true);
pref("extensions.aios.menus.sidebar.paneltab1", false);
pref("extensions.aios.menus.sidebar.paneltab2", false);
pref("extensions.aios.menus.sidebar.showhide", true);
pref("extensions.aios.menus.sidebar.prefs", true);


/*
 *  Shortcuts - by Dorando
 **/
pref("extensions.aios.keyconf.devmode", false);
pref("extensions.aios.keyconf.nicenames.reverse_order", false);
pref("extensions.aios.keyconf.profile", "main");
pref("extensions.aios.keyconf.warnOnClose", false);
pref("extensions.aios.keyconf.warnOnDuplicate", true);


/*
 *  Misc
 **/
pref("extensions.aios.paneltab.reverse", false);
pref("extensions.aios.paneltab.bm", false);
